// 🐦 Flutter imports:
import 'dart:async';

import 'package:dog/dog.dart';
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:pmvvm/pmvvm.dart';

// 🌎 Project imports:
import 'package:adpluginx/Engine/FullScreen/FullScreenEngine.dart';
import 'package:adpluginx/Widget/Loader/LoaderProvider.dart';

class AdEngine {
  static final AdEngine _singleton = AdEngine._internal();

  factory AdEngine() {
    return _singleton;
  }

  AdEngine._internal();

  Timer? timer;

  showFullScreen({
    required BuildContext context,
    String action = "default",
    required Function() onJobComplete,
    bool showLoader = true,
  }) {
    if (showLoader) {
      context.read<LoaderProvider>().isAdLoading = true;
    }
    FullScreenEngine().showAds(
      onTimeOut: () {
        if (showLoader) {
          context.read<LoaderProvider>().isAdLoading = false;
        }
      },
      context: context,
      onJobComplete: () {
        dog.i("Abrt Timer on Job Done =========>", tag: "Timer");
        timer?.cancel();
        if (showLoader) {
          context.read<LoaderProvider>().isAdLoading = false;
        }
        onJobComplete();
      },
    );
    dog.i("Started Timer of 10 Seconds =========>", tag: "Timer");
    timer = Timer.periodic(const Duration(seconds: 10), (timer) {
      dog.i("Condition No Response Ad 10 Second Loader Close =========>",
          tag: "Timer");
      timer.cancel();
      if (showLoader) {
        context.read<LoaderProvider>().isAdLoading = false;
      }
    });
  }

  showActionBasedAds({
    required BuildContext context,
    required String actionName,
    String action = "default",
    required Function() onJobComplete,
    bool showLoader = true,
  }) {
    if (showLoader) {
      context.read<LoaderProvider>().isAdLoading = true;
    }
    FullScreenEngine().showActionAds(
      context: context,
      actionName: actionName,
      onJobComplete: () {
        if (showLoader) {
          context.read<LoaderProvider>().isAdLoading = false;
        }
        onJobComplete();
      },
    );
  }
}
